"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Uses the underlying Writable stream to output GTFS data
 */
class GTFSFileStream {
    constructor(stream, fields, key = null) {
        this.stream = stream;
        this.fields = fields;
        this.key = key;
        this.headerSent = false;
        this.seenKeys = {};
    }
    /**
     * Write the given entity to the file stream
     */
    write(data) {
        if (!this.headerSent) {
            this.stream.write(this.fields.join() + "\n");
            this.headerSent = true;
        }
        const key = this.key ? data[this.key] : null;
        if (!key || !this.seenKeys[key]) {
            this.seenKeys[key] = true;
            const fields = this.fields.map(f => quote(data[f]));
            this.stream.write(fields.join() + "\n");
        }
    }
    /**
     * Close the stream
     */
    end() {
        return new Promise(resolve => this.stream.end(resolve));
    }
}
exports.GTFSFileStream = GTFSFileStream;
function quote(text) {
    return typeof text === "string" && text.includes(",") ? "\"" + text + "\"" : text;
}
