"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const loadGTFS_1 = require("./loadGTFS");
const GTFSFileStream_1 = require("./GTFSFileStream");
const fs = require("fs");
const MergedGTFS_1 = require("./MergedGTFS");
const child_process_1 = require("child_process");
const rimraf_1 = require("rimraf");
const yargs = require("yargs");
async function run(inputs, output, transferDistance) {
    const TMP = "/tmp/gtfsmerge/";
    if (fs.existsSync(TMP)) {
        rimraf_1.sync(TMP);
    }
    fs.mkdirSync(TMP);
    const calendarStream = new GTFSFileStream_1.GTFSFileStream(fs.createWriteStream(TMP + "calendar.txt"), [
        "service_id",
        "monday",
        "tuesday",
        "wednesday",
        "thursday",
        "friday",
        "saturday",
        "sunday",
        "start_date",
        "end_date"
    ], "service_id");
    const calendarDatesStream = new GTFSFileStream_1.GTFSFileStream(fs.createWriteStream(TMP + "calendar_dates.txt"), [
        "service_id",
        "date",
        "exception_type"
    ]);
    const tripsStream = new GTFSFileStream_1.GTFSFileStream(fs.createWriteStream(TMP + "trips.txt"), [
        "route_id",
        "service_id",
        "trip_id",
        "trip_headsign",
        "trip_short_name",
        "direction_id",
        "wheelchair_accessible",
        "bikes_allowed"
    ]);
    const stopTimesStream = new GTFSFileStream_1.GTFSFileStream(fs.createWriteStream(TMP + "stop_times.txt"), [
        "trip_id",
        "arrival_time",
        "departure_time",
        "stop_id",
        "stop_sequence",
        "stop_headsign",
        "pickup_type",
        "drop_off_type",
        "shape_dist_traveled",
        "timepoint"
    ]);
    const routesStream = new GTFSFileStream_1.GTFSFileStream(fs.createWriteStream(TMP + "routes.txt"), [
        "route_id",
        "agency_id",
        "route_short_name",
        "route_long_name",
        "route_type",
        "route_text_color",
        "route_color",
        "route_url",
        "route_desc"
    ], "route_id");
    const agencyStream = new GTFSFileStream_1.GTFSFileStream(fs.createWriteStream(TMP + "agency.txt"), [
        "agency_id",
        "agency_name",
        "agency_url",
        "agency_timezone",
        "agency_lang",
        "agency_phone",
        "agency_fare_url"
    ], "agency_id");
    const stopsStream = new GTFSFileStream_1.GTFSFileStream(fs.createWriteStream(TMP + "stops.txt"), [
        "stop_id",
        "stop_code",
        "stop_name",
        "stop_desc",
        "stop_lat",
        "stop_lon",
        "zone_id",
        "stop_url",
        "location_type",
        "parent_station",
        "stop_timezone",
        "wheelchair_boarding"
    ], "stop_id");
    const transfersStream = new GTFSFileStream_1.GTFSFileStream(fs.createWriteStream(TMP + "transfers.txt"), [
        "from_stop_id",
        "to_stop_id",
        "transfer_type",
        "min_transfer_time"
    ]);
    const mergedGTFS = new MergedGTFS_1.MergedGTFS(calendarStream, calendarDatesStream, tripsStream, stopTimesStream, routesStream, agencyStream, stopsStream, transfersStream, transferDistance);
    for (const input of inputs) {
        console.log("Loading " + input);
        const gtfs = await loadGTFS_1.loadGTFS(input);
        console.log("Processing " + input);
        mergedGTFS.merge(gtfs);
    }
    await mergedGTFS.end();
    await child_process_1.exec(`zip -j ${output} ${TMP}*.txt`, { maxBuffer: Number.MAX_SAFE_INTEGER });
}
const args = yargs.argv;
run(args._.slice(0, args._.length - 1), args._[args._.length - 1], args["transfer-distance"] || 0.02)
    .catch(e => console.error(e));
