"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai = require("chai");
const GTFSFileStream_1 = require("../src/GTFSFileStream");
describe("GTFSFileStream", () => {
    it("Sends the header first", () => {
        const mock = new MockStream();
        const stream = new GTFSFileStream_1.GTFSFileStream(mock, ["field1", "field2"]);
        const expected = "field1,field2\na,b\n";
        stream.write({ field1: "a", field2: "b" });
        chai.expect(mock.data).to.deep.equal(expected);
    });
    it("Does not send duplicate items", () => {
        const mock = new MockStream();
        const stream = new GTFSFileStream_1.GTFSFileStream(mock, ["field1", "field2"], "field1");
        const expected = "field1,field2\na,b\nb,c\n";
        stream.write({ field1: "a", field2: "b" });
        stream.write({ field1: "a", field2: "c" });
        stream.write({ field1: "b", field2: "c" });
        chai.expect(mock.data).to.deep.equal(expected);
    });
});
class MockStream {
    constructor() {
        this.data = "";
    }
    write(chunk) {
        this.data += chunk;
    }
}
